@@ -45,7 +45,7 @@ except ImportError:     # Python 2
                     for cell in rowlst]
 
 
-__version__ = '1.6'
+__version__ = '1.6.1'
 __all__ = ['Client', 'Model', 'Record', 'RecordList', 'Service',
            'format_exception', 'read_config', 'start_odoo_services']
 
@@ -135,8 +135,10 @@ def _convert(node, _consts={'None': None, 'True': True, 'False': False}):
     raise ValueError('malformed or disallowed expression')
 
 
-def literal_eval(expression):
+def literal_eval(expression, _octal_digits=frozenset('01234567')):
     node = compile(expression, '<unknown>', 'eval', _ast.PyCF_ONLY_AST)
+    if expression[:1] == '0' and expression[1:2] in _octal_digits:
+        raise SyntaxError('unsupported octal notation')
     return _convert(node.body)
 
 
@@ -253,12 +255,13 @@ def start_odoo_services(options=None, appname=None):
             odoo.service.start_internal()
         else:   # Odoo v8
             try:
-                odoo.api.Environment._local.environments = odoo.api.Environments()
+                odoo.api.Environment._local.environments = \
+                    odoo.api.Environments()
             except AttributeError:
                 pass
 
         def close_all():
-            for db in odoo.modules.registry.RegistryManager.registries:
+            for db in odoo.modules.registry.RegistryManager.registries.keys():
                 odoo.sql_db.close_db(db)
         atexit.register(close_all)
 
@@ -431,17 +434,19 @@ class Client(object):
             self.login(user, password=password, database=db)
 
     @classmethod
-    def from_config(cls, environment, verbose=False):
+    def from_config(cls, environment, user=None, verbose=False):
         """Create a connection to a defined environment.
 
         Read the settings from the section ``[environment]`` in the
         ``erppeek.ini`` file and return a connected :class:`Client`.
         See :func:`read_config` for details of the configuration file format.
         """
-        (server, db, user, password) = read_config(environment)
+        (server, db, conf_user, password) = read_config(environment)
+        if user and user != conf_user:
+            password = None
         client = cls(server, verbose=verbose)
         client._environment = environment
-        client.login(user, password=password, database=db)
+        client.login(user or conf_user, password=password, database=db)
         return client
 
     def reset(self):
@@ -1583,7 +1588,7 @@ def main(interact=_interact):
         '--server', default=None,
         help='full URL to the XML-RPC server (default: %s)' % DEFAULT_URL)
     parser.add_option('-d', '--db', default=DEFAULT_DB, help='database')
-    parser.add_option('-u', '--user', default=DEFAULT_USER, help='username')
+    parser.add_option('-u', '--user', default=None, help='username')
     parser.add_option(
         '-p', '--password', default=None,
         help='password, or it will be requested on login')
@@ -1612,10 +1617,12 @@ def main(interact=_interact):
         print(USAGE)
 
     if args.env:
-        client = Client.from_config(args.env, verbose=args.verbose)
+        client = Client.from_config(args.env, user=args.user, verbose=args.verbose)
     else:
         if not args.server:
             args.server = ['-c', args.config] if args.config else DEFAULT_URL
+        if not args.user:
+            args.user = DEFAULT_USER
         client = Client(args.server, args.db, args.user, args.password,
                         verbose=args.verbose)
     client.context = {'lang': (os.getenv('LANG') or 'en_US').split('.')[0]}
