@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import with_statement
-
 import mock
 from mock import call, sentinel, ANY
 
@@ -59,7 +57,7 @@ class TestService(XmlRpcTestCase):
         self.assertCalls(call('login', ('aaa',)), 'call().__str__')
         self.assertOutput('')
 
-    def test_service_openerp_client(self, server_version='6.1'):
+    def test_service_openerp_client(self, server_version='8.0'):
         server = 'http://127.0.0.1:8069'
         self.service.side_effect = [server_version, ['newdb'], 1]
         client = erppeek.Client(server, 'newdb', 'usr', 'pss')
@@ -69,20 +67,21 @@ class TestService(XmlRpcTestCase):
         self.assertIsInstance(client.common, erppeek.Service)
         self.assertIsInstance(client._object, erppeek.Service)
         self.assertIsInstance(client._report, erppeek.Service)
-        if server_version == '7.0':
+        if server_version >= '7.0':
             self.assertNotIsInstance(client._wizard, erppeek.Service)
         else:
             self.assertIsInstance(client._wizard, erppeek.Service)
 
-        self.assertIn('/xmlrpc/db', str(client.db.create))
-        if server_version == '5.0':
+        self.assertIn('/xmlrpc/db', str(client.db.create_database))
+        self.assertIn('/xmlrpc/db', str(client.db.db_exist))
+        if server_version == '8.0':
             self.assertRaises(AttributeError, getattr,
-                              client.db, 'create_database')
+                              client.db, 'create')
             self.assertRaises(AttributeError, getattr,
-                              client.db, 'db_exist')
+                              client.db, 'get_progress')
         else:
-            self.assertIn('/xmlrpc/db', str(client.db.create_database))
-            self.assertIn('/xmlrpc/db', str(client.db.db_exist))
+            self.assertIn('/xmlrpc/db', str(client.db.create))
+            self.assertIn('/xmlrpc/db', str(client.db.get_progress))
 
         self.assertCalls(ANY, ANY, ANY)
         self.assertOutput('')
@@ -90,6 +89,9 @@ class TestService(XmlRpcTestCase):
     def test_service_openerp_50(self):
         self.test_service_openerp_client(server_version='5.0')
 
+    def test_service_openerp_61(self):
+        self.test_service_openerp_client(server_version='6.1')
+
     def test_service_openerp_70(self):
         self.test_service_openerp_client(server_version='7.0')
 
@@ -126,14 +128,23 @@ class TestCreateClient(XmlRpcTestCase):
         getpass = mock.patch('getpass.getpass',
                              return_value='password').start()
         self.service.db.list.return_value = ['database']
-
-        client = erppeek.Client('http://127.0.0.1:8069', 'database', 'usr')
         expected_calls = self.startup_calls + (
             ('common.login', 'database', 'usr', 'password'),)
+
+        # A: Invalid login
+        self.assertRaises(erppeek.Error, erppeek.Client,
+                          'http://127.0.0.1:8069', 'database', 'usr')
+        self.assertCalls(*expected_calls)
+        self.assertEqual(getpass.call_count, 1)
+
+        # B: Valid login
+        self.service.common.login.return_value = 17
+        getpass.reset_mock()
+
+        client = erppeek.Client('http://127.0.0.1:8069', 'database', 'usr')
         self.assertIsInstance(client, erppeek.Client)
         self.assertCalls(*expected_calls)
         self.assertEqual(getpass.call_count, 1)
-        self.assertOutput('Error: Invalid username or password\n')
 
     def test_create_with_cache(self):
         self.service.db.list.return_value = ['database']
@@ -156,15 +167,25 @@ class TestCreateClient(XmlRpcTestCase):
         getpass = mock.patch('getpass.getpass',
                              return_value='password').start()
         self.service.db.list.return_value = ['database']
-
-        client = erppeek.Client.from_config('test')
         expected_calls = self.startup_calls + (
             ('common.login', 'database', 'usr', 'password'),)
+
+        # A: Invalid login
+        self.assertRaises(erppeek.Error, erppeek.Client.from_config, 'test')
+        self.assertCalls(*expected_calls)
+        self.assertEqual(read_config.call_count, 1)
+        self.assertEqual(getpass.call_count, 1)
+
+        # B: Valid login
+        self.service.common.login.return_value = 17
+        read_config.reset_mock()
+        getpass.reset_mock()
+
+        client = erppeek.Client.from_config('test')
         self.assertIsInstance(client, erppeek.Client)
         self.assertCalls(*expected_calls)
         self.assertEqual(read_config.call_count, 1)
         self.assertEqual(getpass.call_count, 1)
-        self.assertOutput('Error: Invalid username or password\n')
 
 
 class TestSampleSession(XmlRpcTestCase):
@@ -274,24 +295,18 @@ class TestClientApi(XmlRpcTestCase):
 
     def test_create_database(self):
         create_database = self.client.create_database
-        mock.patch('time.sleep').start()
-        self.client.db.create.return_value = ID1
-        self.client.db.get_progress.return_value = \
-            [1, [{'login': 'LL', 'password': 'PP'}]]
         self.client.db.list.side_effect = [['db1'], ['db2']]
 
         create_database('abc', 'db1')
         create_database('xyz', 'db2', user_password='secret', lang='fr_FR')
 
         self.assertCalls(
-            call.db.create('abc', 'db1', False, 'en_US', 'admin'),
-            call.db.get_progress('abc', ID1),
+            call.db.create_database('abc', 'db1', False, 'en_US', 'admin'),
             call.db.list(),
-            call.common.login('db1', 'LL', 'PP'),
-            call.db.create('xyz', 'db2', False, 'fr_FR', 'secret'),
-            call.db.get_progress('xyz', ID1),
+            call.common.login('db1', 'admin', 'admin'),
+            call.db.create_database('xyz', 'db2', False, 'fr_FR', 'secret'),
             call.db.list(),
-            call.common.login('db2', 'LL', 'PP'),
+            call.common.login('db2', 'admin', 'secret'),
         )
         self.assertOutput('')
 
@@ -326,11 +341,9 @@ class TestClientApi(XmlRpcTestCase):
         )
         self.assertOutput('')
 
-        warn = mock.patch('warnings.warn').start()
+        # No longer supported since 1.6
         search('foo.bar', 'name like Morice')
-        self.assertCalls(OBJ('foo.bar', 'search', domain))
-        warn.assert_called_once_with(
-            "Domain should be a list: ['name like Morice']")
+        self.assertCalls(OBJ('foo.bar', 'search', 'name like Morice'))
 
         search('foo.bar', ['name like Morice'], missingkey=42)
         self.assertCalls(OBJ('foo.bar', 'search', domain, 0, None, None, None))
@@ -366,11 +379,9 @@ class TestClientApi(XmlRpcTestCase):
         )
         self.assertOutput('')
 
-        warn = mock.patch('warnings.warn').start()
+        # No longer supported since 1.6
         count('foo.bar', 'name like Morice')
-        self.assertCalls(OBJ('foo.bar', 'search_count', domain))
-        warn.assert_called_once_with(
-            "Domain should be a list: ['name like Morice']")
+        self.assertCalls(OBJ('foo.bar', 'search_count', 'name like Morice'))
 
         self.assertRaises(TypeError, count)
         self.assertRaises(TypeError, count,
@@ -494,18 +505,16 @@ class TestClientApi(XmlRpcTestCase):
 
     def test_read_invalid(self):
         read = self.client.read
+        self.service.object.execute.side_effect = self.obj_exec
         domain = [('name', 'like', 'Morice')]
 
-        warn = mock.patch('warnings.warn').start()
+        # No longer supported since 1.6
         read('foo.bar', 'name like Morice')
-        warn.assert_called_once_with(
-            "Domain should be a list: ['name like Morice']")
 
         read('foo.bar', ['name like Morice'], missingkey=42)
 
         self.assertCalls(
-            OBJ('foo.bar', 'search', domain),
-            OBJ('foo.bar', 'read', ANY, None),
+            OBJ('foo.bar', 'read', ['name like Morice'], None),
             OBJ('foo.bar', 'search', domain, 0, None, None, None),
             OBJ('foo.bar', 'read', ANY, None))
         self.assertOutput('Ignoring: missingkey = 42\n')
@@ -557,12 +566,11 @@ class TestClientApi(XmlRpcTestCase):
         )
         self.assertOutput('')
 
-        self.assertIsNone(self.client.model('foo.bar'))
+        self.assertRaises(erppeek.Error, self.client.model, 'foo.bar')
         self.assertCalls(
             OBJ('ir.model', 'search', [('model', 'like', 'foo.bar')]),
             OBJ('ir.model', 'read', [ID2, ID1], ('model',)),
         )
-        self.assertIn('Model not found', self.stdout.popvalue())
         self.assertOutput('')
 
         self.service.object.execute.side_effect = [
@@ -728,6 +736,29 @@ class TestClientApi50(TestClientApi):
         pass
     test_execute_kw = test_render_report = _skip
 
+    def test_create_database(self):
+        create_database = self.client.create_database
+        mock.patch('time.sleep').start()
+        self.client.db.create.return_value = ID1
+        self.client.db.get_progress.return_value = \
+            [1, [{'login': 'admin', 'password': 'PP'}]]
+        self.client.db.list.side_effect = [['db1'], ['db2']]
+
+        create_database('abc', 'db1')
+        create_database('xyz', 'db2', user_password='secret', lang='fr_FR')
+
+        self.assertCalls(
+            call.db.create('abc', 'db1', False, 'en_US', 'admin'),
+            call.db.get_progress('abc', ID1),
+            call.db.list(),
+            call.common.login('db1', 'admin', 'admin'),
+            call.db.create('xyz', 'db2', False, 'fr_FR', 'secret'),
+            call.db.get_progress('xyz', ID1),
+            call.db.list(),
+            call.common.login('db2', 'admin', 'secret'),
+        )
+        self.assertOutput('')
+
     def _module_upgrade(self, button='upgrade'):
         self.service.object.execute.side_effect = [
             [7, 0], [42], {'name': 'Upgrade'}, [4, 42, 5],
